__version__ = "0.2.13"

__release_notes__ = {
    # "0.1.6": {
    #    "STATUS":[
    #             "This version get lot of changes and may contain bugs or missing features, please provide any feedback to improve and prepare a better future release !"
    #         ],
    #    "A2P2": [
    #
    #        ],
    #    "VLTI": [
    #
    #        ],
    #    "CHARA": [
    #
    #        ],
    #    "TODO-SCIENCE": [
    #
    #        ],
    #    "TODO-DEV": [
    #
    #        ],
    #    },
    "0.2.13": {
        "STATUS": [
        ],
        "A2P2": [
            "A2P2 is now longer python2 compatible. Hope it will be ok for everybody ? Send an issue else ;)",
            "Fix generated release note order according to semver values",
            "Dry tests done looping on a few OBXML files"
            "Added -c option to a2p2 so we generated a config file ( helps to automatically fill P2 login info & autologin : )"
        ],
        "VLTI": [
            "Conf updated with IPs 106.25",
            "OB no more sent to P2 if OB's instrument is not the same than p2 selected container"
        ],
        "CHARA": [
        ],
        "TODO-SCIENCE": [
            "Check DIT table from last template user manuals",
            "Use a calibrator template for MATISSE (instead of default hyb_obs)",
            "flag ~important~ keywords which MUST be set in a2p2 code and not leaved to there default values"
        ],
        "TODO-DEV": [
            "Support multiple period version (two major at least)",
            "Add warning if Aspro2's IP versions differs from the selected container" ,
            "Support numlist keyword : eg. SEQ.HWPOFF",
            "Optimize VLTI run chooser : DEMO tests suffer from a long run filtering",
            "Unify ob name creation in vlti instrument createOB()",
            "Complete test suite with real p2 submission"
        ],
    },
    "0.2.12": {
        "STATUS": [
        ],
        "A2P2": [
            "Fix import in main console script"
        ],
        "VLTI": [
        ],
        "CHARA": [
        ],
    },
    "0.2.11": {
        "STATUS": [
        ],
        "A2P2": [
            "enhance setup.py so it install Windows special-cases .exe files"
        ],
        "VLTI": [
        ],
        "CHARA": [
        ],
    },
    "0.2.10": {
        "STATUS": [
        ],
        "A2P2": [
            "Patch bad SAMP url handling on Windows"
        ],
        "VLTI": [
        ],
        "CHARA": [
        ],
    },
    "0.2.9": {
        "STATUS": [
        ],
        "A2P2": [

        ],
        "VLTI": [
            "Fix bug that prevent to create any folder or concatenation at RUNS's root"
        ],
        "CHARA": [

        ],
        "TODO-SCIENCE": [

        ],
        "TODO-DEV": [

        ],
    },
    "0.2.8": {
        "STATUS": [
        ],
        "A2P2": [
            "Fix release notes order in the GUI",
            "Handle special jmmc account, kindly set by ESO colleagues to perfom future tests as closed as possible to the real UX"
        ],
        "VLTI": [
            "Display instrument package version in the container table",
            "Limit keyword set on P2 only to the modified ones. No more default values from our static config are sent so it enhances compatibility accross multiple Period versions",
        ],
        "CHARA": [
        ],
        "TODO-SCIENCE": [
        ],
        "TODO-DEV": [
        ]
    }, "0.2.7": {
        "STATUS": [
            "This version get lot of changes and may contain bugs or missing features, please provide any feedback to improve and prepare a better future release !"
        ],
        "A2P2": [
            "Refactor code accross vlti instruments",
            "Fix container selection in P2 tree"
            "Add release notes in the GUI"
        ],
        "VLTI": [
            "Conf updated with IPs 105.18",
            "Add MATISSE support",
            "Change GRAVITY DIT computation",
            "OB constraints autochecked using an instrumentConstraints TSF",
            "Support Concatenations (also shown in the tree panel)",
            "Show type in the container chooser instead of containerID"
        ],
        "CHARA": [
        ],
        "TODO-SCIENCE": [
            "Complete/fix GRAVITY DIT table with P105 changes that will come in the next template user manual",
            "Use a calibrator template for MATISSE (instead of default hyb_obs)",
            "flag ~important~ keyword that MUST be set in a2p2 code to avoid default"
        ],
        "TODO-DEV": [
            "Support numlist keyword : eg. SEQ.HWPOFF",
            "Optimize VLTI run chooser : DEMO tests suffer from a long run filtering",
            "Do not set default values in a2p2 if not set",
            "unify ob name creation in vlti instrument createOB()"
        ]
    }, "0.2.6": {
        "A2P2": [

        ],
        "VLTI": [
            "Support baseline back again (single one at present)"
        ],
        "CHARA": [

        ]
    },
    "0.2.5": {
        "A2P2": [

        ],
        "VLTI": [
            "Add missing template name in log",
            "Fix error removing baseline after constraint changes on P2 side. Next a2p2 version should add them back in acq templates"
        ],
        "CHARA": [

        ]
    },
    "0.2.4": {
        "A2P2": [

        ],
        "VLTI": [
            "Fix bug / wrong keys"
        ],
        "CHARA": [

        ]
    },
    "0.2.3": {
        "A2P2": [

        ],
        "VLTI": [
            "Hide password in login frame"
        ],
        "CHARA": [

        ]
    },
    "0.2.2": {
        "A2P2": [

        ],
        "VLTI": [
            "ignore default time constraints computed by Aspro"
        ],
        "CHARA": [

        ]
    },
    "0.2.1": {
        "A2P2": [

        ],
        "VLTI": [
            "fix support for a list of multiples time constraints"
        ],
        "CHARA": [

        ]
    },
    "0.2.0": {
        "A2P2": [

        ],
        "VLTI": [
            "bug fix"
        ],
        "CHARA": [

        ]
    },
    "0.1.6": {
        "A2P2": [
            "Major code reformating - pep8 compliant"
        ],
        "VLTI": [
            "general config updates",
            "add PIONIER"
        ],
        "CHARA": [

        ]
    },
    "0.1.5": {
        "A2P2": [

        ],
        "VLTI": [
            "bugfix for dualfield cases"
        ],
        "CHARA": [

        ]
    },
    "0.1.4": {
        "A2P2": [
            "fix order of returned fluxes in OB.getFluxes()"
        ]
    },
    "0.1.3": {
        "VLTI": [
            "fix telescope mode computation"
        ]
    },
    "0.1.2": {
        "A2P2": [
            "bugfix for SPLIT polarisation mode detection on GRAVITY",
            "bugfix that displays warning message during DIT calculation in GRAVITY LR mode",
            "enhancement of out of bound exception message of DIT calculation method"
        ]
    },
    "0.1.1": {
        "A2P2": [
            "muti-faciliy",
            "multi-VltiInstruments",
            "json VltiConfig (templates+dit tables)"
        ]
    }
}



#!/usr/bin/env python

__all__ = []


class Instrument():

    def __init__(self, facility, insname, help="Help TBD"):
        self.facility = facility
        self.insname = insname
        self.help = help
        facility.registerInstrument(self)

    def getName(self):
        return self.insname

    def getShortName(self):
        """
        Keep left part of _ tokenized name.
        EG. useful to replace MATISSE_LM or MATISSE_N by MATISSE in some common parts (config or treeview).
        """
        if not "_" in self.insname:
            return self.insname
        return self.insname[0:self.insname.index("_")]

    def getHelp(self):
        return self.help



#!/usr/bin/env python

__all__ = []


class FacilityManager():
    """
    Manage real and fake apis.
    """

    def __init__(self, a2p2client):
        self.apiName = a2p2client.apiName
        self.a2p2client = a2p2client

        # define facilities
        self.facilities = {}
        from a2p2.chara.facility import CharaFacility
        self.registerFacility(CharaFacility(self.a2p2client))
        from a2p2.vlti.facility import VltiFacility
        self.registerFacility(VltiFacility(self.a2p2client))
        # with default one
        self.defaultFacility = Facility(self.a2p2client, "Dumm-facilit-y", "")

    def registerFacility(self, facilityObject):
        self.facilities[facilityObject.facilityName] = facilityObject
        self.a2p2client.ui.addHelp(
            facilityObject.facilityName, facilityObject.facilityHelp)

    def get_status(self):
        status = []
        for facility in self.facilities.values():
            if facility.getStatus():
                status.append(
                    facility.facilityName + " [" + facility.getStatus() + " ]")

        return " | ".join(status)

    def processOB(self, ob):
        """ Test instrument on facility that registerInstrument() before OB forward for specialized handling."""
        interferometer = ob.interferometerConfiguration.name
        insname = ob.instrumentConfiguration.name

        if interferometer in self.facilities:
            facility = self.facilities[interferometer]
        else:
            facility = self.defaultFacility

        supportedIns = facility.getSupportedInsnames()
        if len(supportedIns) == 0 or insname in supportedIns:
            self.a2p2client.ui.addToLog(
                "Received OB for '" + insname + "@" + interferometer + "' ")
            facility.processOB(ob)
        else:
            self.a2p2client.ui.ShowErrorMessage("Received OB for unsupported instrument \n" +
                                                insname + " @ " + interferometer + "\n" + "Supported instrument(s): " + ", ".join(
                                                    supportedIns))


# TODO move to a dedicated source file
class Facility():

    def __init__(self, a2p2client, facilityName, facilityHelp):
        self.a2p2client = a2p2client
        self.facilityName = facilityName
        self.facilityHelp = facilityHelp
        self.facilityInstruments = {}

    def processOB(self, ob):
        """ Please override this method in your facility class to handle incoming OB. """
        interferometer = ob.interferometerConfiguration.name
        self.a2p2client.ui.addToLog(
            "'" + interferometer + "' interferometer not supported by A2P2")

    def registerInstrument(self, instrument):
        self.facilityInstruments[instrument.getName()] = instrument

    def getSupportedInsnames(self):
        return self.facilityInstruments.keys()

    def hasSupportedInsname(self, insname):
        # ... we may log failures
        if insname in self.getSupportedInsnames():
            return True
        for i in self.getSupportedInstruments():
            if i.getShortName() == insname:
                return True

    def getSupportedInstruments(self):
        return self.facilityInstruments.values()

    def getInstrument(self, insname):
        return self.facilityInstruments[insname]

    def getName(self):
        return self.facilityName

    def getStatus(self):
        """ Please override this method in your facility class to include status in the API entry of the main status bar. """
        return None



from setuptools import setup, find_packages

with open('README.rst') as README:
    long_description = README.read()
    description = long_description[
        :long_description.index('Description')].split("*")[1].strip()
    long_description = long_description[long_description.index('Description'):]

version = {}
with open("a2p2/version.py") as fp:
    exec(fp.read(), version)

setup(
    name='a2p2',
    version=version['__version__'],
    description=description,
    long_description=long_description,
    #      install_requires=['astropy', 'p2api','pygtk'],
    # PyGtk is not working on some linux
    # anaconda also fails
    # prefere the use of your default python packages on your linux
    # what is the solution for mac ?
    # we continue moving tk as first gui backend
    # install_requires=['astropy', 'p2api', 'python-tk'] + (['pygtk'] if
    # platform.startswith("win") else []),
    install_requires=['astropy>=2', 'p2api', 'appdirs'],
    url='http://www.jmmc.fr/a2p2',
    author='JMMC Tech Group',
    author_email='jmmc-tech-group@jmmc.fr',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
#        'Programming Language :: Python :: 2',
#        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
    ],
    license='OSI Approved :: GNU General Public License v3 (GPLv3)',
    packages=find_packages(),
    include_package_data=True,
    entry_points={'console_scripts': ['a2p2=a2p2.__main__:main']},
    keywords='observation preparation tool optical-interferometry p2 samp'
)



#!/usr/bin/env python

__all__ = []

import sys

from a2p2.gui import FacilityUI

if sys.version_info[0] == 2:
    from Tkinter import *
    from tkMessageBox import *
    import ttk
else:
    from tkinter import *
    from tkinter.messagebox import *
    import tkinter.ttk as ttk


class VltiUI(FacilityUI):

    def __init__(self, a2p2client):
        FacilityUI.__init__(self, a2p2client)

        self.container = Frame(self, bd=3, relief=SUNKEN)
        self.container.grid_rowconfigure(0, weight=1)
        self.container.grid_columnconfigure(0, weight=1)

        self.loginFrame = LoginFrame(self)
        self.loginFrame.grid(row=0, column=0, sticky="nsew")

        self.treeFrame = TreeFrame(self)
        self.treeFrame.grid(row=0, column=0, sticky="nsew")
        self.tree = self.treeFrame.tree

        self.container.pack(fill=BOTH, expand=True)
        self.treeItemToRuns = {}
        self.treeItemToP2Items = {}

        self.ob=None

    def showLoginFrame(self, ob):
        self.ob = ob
        self.addToLog(
            "Sorry, your %s OB can't be submitted, please log in first, select container and send OB again from Aspro2." %
            (ob.instrumentConfiguration.name))
        self.loginFrame.tkraise()

    def showTreeFrame(self, ob=None):
        if ob:
            instrum = ob.instrumentConfiguration.name
        else:
            instrum = "incoming"
        self.addToLog("Please select a runId in ESO P2 database to process %s OB" % instrum )
        self.treeFrame.tkraise()

    def fillTree(self, runs):
        if len(runs) == 0:
            self.ShowErrorMessage(
                "No Runs defined, impossible to program ESO's P2 interface.")
            return
        # cleanup old entries if any
        for item in self.treeItemToRuns:
            try:
                self.tree.delete(item)
            except:
                pass
        self.treeItemToRuns = {}

        for run in runs:
            if self.facility.hasSupportedInsname(run['instrument']):
                cid = run['containerId']
                self._insertInTree('', run['progId'], cid, run, run)
                # if folders, add them recursively
                folders = getFolders(self.facility.api, cid)
                if len(folders) > 0:
                    try:
                        self.folder_explore(folders, cid, run)
                    except:
                        pass

    def folder_explore(self, folders, contid, run):
        for folder in folders:
            self._insertInTree(
                contid, folder['name'], folder['containerId'], run, folder)
            folders2 = getFolders(self.facility.api, folder['containerId'])
            if len(folders2) > 0:
                try:
                    self.folder_explore(folders2, folder['containerId'], run)
                except:
                    pass

    def _insertInTree(self, parentContainerID, name, containerID, run, item):
        instrument = run['instrument']
        if run != item:
            label = item['itemType']
        else:
            # {"runId":60900301,"progId":"60.A-9003(B)","title":"Tutorial account","period":60,
            # "scheduledPeriod":60,"mode":"VM","instrument":"FORS2","telescope":"UT1","ipVersion":104.26,
            # "isToO":false,"owned":true,"delegated":false,"itemCount":0,"containerId":2587672,
            # "pi":{"emailAddress":"52052@nodomain.net","firstName":"Phase 1/2 Tutorial","lastName":"Account"},
            # "observingConstraints":{"seeing":2.0}}
            label = "%s Run (IP %s)" % (run['mode'], run['ipVersion'])

        e = self.tree.insert(parentContainerID, 'end', containerID,
                             text=name, values=(run['instrument'], label))
        self.treeItemToRuns[e] = run
        self.treeItemToP2Items[e] = item

    def on_tree_selection_changed(self, selection):
        curItem = self.tree.focus()
        ret = self.tree.item(curItem)
        if len(ret['values']) > 0:
            self.facility.containerInfo.store(
                self.treeItemToRuns[curItem], self.treeItemToP2Items[curItem])

    def isBusy(self):
        self.tree.configure(selectmode='browse')

    def isIdle(self):
        self.tree.configure(selectmode='none')


class TreeFrame(Frame):

    def __init__(self, vltiUI):
        Frame.__init__(self, vltiUI.container)
        self.vltiUI = vltiUI

        subframe = Frame(self)

        self.tree = ttk.Treeview(
            subframe, columns=('Project ID'))  # , 'instrument'))#, 'folder ID'))
        ysb = ttk.Scrollbar(
            subframe, orient='vertical', command=self.tree.yview)
        xsb = ttk.Scrollbar(
            subframe, orient='horizontal', command=self.tree.xview)

        self.tree.configure(yscroll=ysb.set, xscroll=xsb.set)
        self.tree.heading('#0', text='Project ID', anchor='w')
        self.tree.heading('#1', text='Instrument', anchor='w')
        self.tree.heading('#2', text='Container type', anchor='w')
        self.tree.bind(
            '<ButtonRelease-1>', self.vltiUI.on_tree_selection_changed)

        # grid layout does not expand and fill all area then move to pack
        #       self.tree.grid(row=0, column=0, sticky='nsew')
        #       ysb.grid(row=0, column=1, sticky='ns')
        #       xsb.grid(row=1, column=0, sticky='ew')
        self.tree.pack(side=LEFT, fill=BOTH, expand=True)
        ysb.pack(side=RIGHT, fill="y")
        # xsb.pack(side=BOTTOM, fill="y") # will probably require to add
        # another 2 frames

        subframe.pack(side=TOP, fill=BOTH, expand=True)


class LoginFrame(Frame):

    def __init__(self, vltiUI):
        Frame.__init__(self, vltiUI.container)
        self.vltiUI = vltiUI

        prefs = vltiUI.a2p2client.preferences

        self.loginframe = LabelFrame(
            self, text="login (ESO USER PORTAL or demo account)")

        self.username_label = Label(self.loginframe, text="USERNAME")
        self.username_label.pack()
        self.username = StringVar()
        self.username.set(prefs.getP2Username())
        self.username_entry = Entry(
            self.loginframe, textvariable=self.username)
        self.username_entry.pack()

        self.password_label = Label(self.loginframe, text="PASSWORD")
        self.password_label.pack()
        self.password = StringVar()
        self.password.set(prefs.getP2Password())
        self.password_entry = Entry(
            self.loginframe, textvariable=self.password, show="*")
        self.password_entry.pack()

        self.loginbutton = Button(
            self.loginframe, text="LOG IN", command=self.on_loginbutton_clicked)
        self.loginbutton.pack()

        self.loginframe.pack()
        self.pack(side=TOP, fill=BOTH, expand=True)

    def on_loginbutton_clicked(self):
        self.vltiUI.facility.connectAPI(
            self.username.get(), self.password.get(), self.vltiUI.ob)


# TODO move into a common part
def getFolders(p2api, containerId):
    folders = []
    items, _ = p2api.getItems(containerId)
    for item in items:
        if item['itemType'] in ['Folder', 'Concatenation']:
            folders.append(item)
    return folders



#!/usr/bin/env python

__all__ = []

import os
import traceback

from a2p2.facility import Facility
from a2p2.vlti.gui import VltiUI

MODE_SM = 'SM'

ITEMTYPE_CONCATENATION = 'Concatenation'

JMMC_LOGIN = 'jmmc'

TUTORIAL_LOGIN = '52052'
PRODUCTION_APITYPE = 'production'
DEMO_APITYPE = 'demo'

# TODO handle a period subdirectory
CONFDIR = "conf"

# Look for configuration files in the same level directory as this module/conf/
try:
    _confdir = os.path.join(os.path.dirname(__file__), CONFDIR)
except NameError:
    _confdir = CONFDIR
if os.path.isdir(_confdir):
    CONFDIR = _confdir
elif not os.path.isdir(CONFDIR):
    raise RuntimeError("can't find conf directory (%r)" % (CONFDIR,))

HELPTEXT = """
ESO's P2 repository for Observing Blocks (OBs):


Send configuration from Aspro:
- In ASPRO, have an object, or an object selected, and check that all important informations (magnitudes, but also Instrument and Fringe Tracker Modes, eventually hour angles), are correctly set.
- In menu "Interop" select "Send Obs. blocks to A2p2"
- Block(s) are created and put in the P2 repository.
- If the source had one or more calibrators, blocks are created for them too.
- For each block submitted, a report is produced. Warnings are usually not significant.
- For more than 1 object sent, a <b>folder</b> containing the two or more blocks is created. In the absence of availability of grouping OBs (like for CAL-SCI-CAL) provided by ESO, this is the closets we can do.
- All the new OBs and folders will be available on p2web at https://www.eso.org/p2

On your first valid VLTI's OB, A2p2 will ask for your ESO User Portal credentials to interact with P2 using it's API. You can follow actions and organize more in details your OB on https://www.eso.org/p2 . Please use prefilled values of the login panel for testing purpose and follow ESO database from https://www.eso.org/p2demo/
"""
HELPTEXT += "Config files loaded from " + CONFDIR


class VltiFacility(Facility):

    def __init__(self, a2p2client):
        Facility.__init__(self, a2p2client, VltiFacility.getName(), HELPTEXT)
        self.ui = VltiUI(self)

        # Instanciate instruments
        # TODO complete list and make it more object oriented
        from a2p2.vlti.gravity import Gravity
        gravity = Gravity(self)
        from a2p2.vlti.pionier import Pionier
        pionier = Pionier(self)
        from a2p2.vlti.matisse import Matisse
        matisse = Matisse(self)

        # complete help
        for i in self.getSupportedInstruments():
            self.facilityHelp += "\n" + i.getHelp()

        self.connected = False
        # set to demo by default (may change in connectAPI)
        self.apitype = 'demo'
        self.containerInfo = P2Container(self)

        # will store later : name for status info, api
        self.username = None
        self.api = None

    def getName():
        return "VLTI"

    def autologin(self):
        self.ui.loginFrame.on_loginbutton_clicked()
        self.a2p2client.ui.showFacilityUI(self.ui)
        self.ui.showTreeFrame()

    def processOB(self, ob):
        # give focus on last updated UI
        self.a2p2client.ui.showFacilityUI(self.ui)
        # show ob dict for debug
        self.ui.addToLog(str(ob), False)

        # OB is checked and submitted by instrument
        instrument = self.getInstrument(ob.instrumentConfiguration.name)
        try:
            # run checkOB which may raise some error before connection request
            instrument.checkOB(ob)

            insname = instrument.getShortName()
            containerInsname = self.containerInfo.getInstrument()

            # performs operation
            if not self.isConnected():
                self.ui.showLoginFrame(ob)
            elif not self.isReadyToSubmit():
                # self.a2p2client.ui.addToLog("Receive OB for
                # '"+ob.instrumentConfiguration.name+"'")
                self.ui.addToLog(
                    "Please select a folder (not a concatenation) in the above list. OBs are not shown")
            elif  insname.lower() != containerInsname.lower():
                self.ui.ShowErrorMessage("Aborting: container's instrument '%s' in not applicable for received OB's one '%s'." %(containerInsname,insname))
            else:
                self.ui.addToLog(
                    "everything ready! Request OB creation inside selected container ")
                instrument.submitOB(ob, self.containerInfo)
                self.refreshTree()

        # TODO add P2Error handling P2Error(r.status_code, method, url,
        # r.json()['error'])
        except ValueError as e:
            traceback.print_exc()
            trace = traceback.format_exc(limit=1)
            # ui.ShowErrorMessage("Value error :\n %s \n%s\n\n%s" % (e, trace,
            # "Aborting submission to P2. Look at the whole traceback in the log."))
            self.ui.ShowErrorMessage("Value error :\n %s \n\n%s" %
                                     (e, "Aborting submission to P2. Please check LOG and fix before new submission."))
            trace = traceback.format_exc()
            self.ui.addToLog(trace, False)
            self.ui.setProgress(0)
        except Exception as e:
            traceback.print_exc()
            # limit = 2 should raise errors in our codes
            trace = traceback.format_exc(limit=1)
            self.ui.ShowErrorMessage(
                "General error or Absent Parameter in template!\n Missing magnitude or OB not set ?\n\nError :\n %s \n Please check LOG and fix before new submission." % (
                    trace))
            trace = traceback.format_exc()
            self.ui.addToLog(trace, False)
            self.ui.setProgress(0)

    def isReadyToSubmit(self):
        return self.api and self.containerInfo.isOk()

    def isConnected(self):
        return self.connected

    def setConnected(self, flag):
        self.connected = flag

    def getStatus(self):
        if self.isConnected():
            return " P2API connected with " + self.username

    def connectAPI(self, username, password, ob):
        import p2api
        if username == TUTORIAL_LOGIN or username == JMMC_LOGIN:
            self.apitype = DEMO_APITYPE
        else:
            self.apitype = PRODUCTION_APITYPE
        try:
            self.api = p2api.ApiConnection(self.apitype, username, password)
            # TODO test that api is ok and handle error if any...

            self.refreshTree()

            self.setConnected(True)
            self.username = username
            self.ui.showTreeFrame(ob)
        except:
            self.ui.addToLog("Can't connect to P2 (see LOG).")
            trace = traceback.format_exc()
            self.ui.addToLog(trace, False)

    def refreshTree(self):
        runs, _ = self.api.getRuns()
        self.ui.fillTree(runs)

    def isDemoAPI(self):
        return self.apitype == DEMO_APITYPE

    def isTutorialAccount(self):
        return self.username == TUTORIAL_LOGIN

    def getAPI(self):
        return self.api

    def getConfDir(self):
        """
        returns the configuration directory with instrument's json files
        """
        return CONFDIR


# TODO Move code out of this class


class P2Container:
    # run object stores:
    # {'pi': {'lastName': 'Accont', 'emailAddress': '52052@nodomain.net', 'firstName': 'Phase 1/2 Ttorial'},
    # 'telescope': 'VLTI', 'title': 'p2 tutorial', 'schedledPeriod': 60, 'isToO': False, 'period': 60, 'owned': Tre,
    # 'ipVersion': 104.05, 'instrument': 'PIONIER', 'containerId': 1601182, 'observingConstraints': {'fli' : 'd', 'seeing': 0.8},
    # 'mode': 'SM', 'progId': '60.A-9253(T)', 'itemCont': 2, 'delegated': False, 'runId': 60925319}
    # and item (when not run) :
    # {u'containerStatus': u'P', u'itemType': u'Group', u'name': u'New Group', u'groupScore': 0.0,
    # u'containerId': 2609528, u'runId': 60925213, u'userPriority': 1, u'itemCount': 0, u'parentContainerId': 2609516}

    def __init__(self, facility):
        self.facility = facility
        self.run = None  # dict returned by p2api
        self.containerId = None
        self.item = None

    def store(self, run, item):
        self.run = run
        self.item = item
        self.containerId = item['containerId']
        self.log()

    def log(self):
        if self.run != self.item and self.item['itemType'] == ITEMTYPE_CONCATENATION:
            self.facility.ui.addToLog(
                "*** Please do not select a Concatenation and select another container. ***")
        else:
            self.facility.ui.addToLog("*** Working with %s ***" % self)

    def isOk(self):
        if self.run == None:
            return False
        if self.run == self.item:
            return True
        return self.item['itemType'] != ITEMTYPE_CONCATENATION

    def getInstrument(self):
        return self.run['instrument']

    def isRoot(self):
        return self.item.keys() != None and 'pi' in self.item.keys()

    def isServiceModeRun(self):
        return self.run['mode'] == MODE_SM

    def __str__(self):
        return """instrument:'%s', containerId:'%s'""" % (self.run['instrument'], self.containerId)
